@@ -45,6 +45,7 @@ Config::initDefaultValues (void)
     m_remember_every_input = FALSE;
     m_sort_option = SORT_BY_PHRASE_LENGTH_AND_PINYIN_LENGTH_AND_FREQUENCY;
     m_show_suggestion = FALSE;
+    m_emoji_candidate = TRUE;
 
     m_shift_select_candidate = FALSE;
     m_minus_equal_page = TRUE;
@@ -66,6 +67,7 @@ Config::initDefaultValues (void)
     m_main_switch = "<Shift>";
     m_letter_switch = "";
     m_punct_switch = "<Control>period";
+    m_both_switch = "";
     m_trad_switch = "<Control><Shift>f";
 }
 
