@@ -48,6 +48,7 @@ public:
     gboolean rememberEveryInput (void) const    { return m_remember_every_input; }
     sort_option_t sortOption (void) const       { return m_sort_option; }
     gboolean showSuggestion (void) const        { return m_show_suggestion; }
+    gboolean emojiCandidate (void) const        { return m_emoji_candidate; }
     gboolean shiftSelectCandidate (void) const  { return m_shift_select_candidate; }
     gboolean minusEqualPage (void) const        { return m_minus_equal_page; }
     gboolean commaPeriodPage (void) const       { return m_comma_period_page; }
@@ -68,6 +69,7 @@ public:
     std::string mainSwitch (void) const         { return m_main_switch; }
     std::string letterSwitch (void) const       { return m_letter_switch; }
     std::string punctSwitch (void) const        { return m_punct_switch; }
+    std::string bothSwitch (void) const         { return m_both_switch; }
     std::string tradSwitch (void) const         { return m_trad_switch; }
     std::string openccConfig (void) const       { return m_opencc_config; }
 
@@ -100,6 +102,7 @@ protected:
     gboolean m_remember_every_input;
     sort_option_t m_sort_option;
     gboolean m_show_suggestion;
+    gboolean m_emoji_candidate;
 
     gboolean m_shift_select_candidate;
     gboolean m_minus_equal_page;
@@ -125,6 +128,7 @@ protected:
     std::string m_main_switch;
     std::string m_letter_switch;
     std::string m_punct_switch;
+    std::string m_both_switch;
     std::string m_trad_switch;
 
 };
