@@ -366,7 +366,7 @@ EnglishEditor::EnglishEditor (PinyinProperties & props, Config &config)
     m_english_database = new EnglishDatabase;
 
     gchar *path = g_build_filename (g_get_user_cache_dir (),
-                                     "ibus", "pinyin", "english-user.db", NULL);
+                                     "ibus", "libpinyin", "english-user.db", NULL);
 
     gboolean result = m_english_database->openDatabase
         (".." G_DIR_SEPARATOR_S "data" G_DIR_SEPARATOR_S "english.db",
@@ -418,11 +418,11 @@ EnglishEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
 
     /* Remember the input string. */
     if (m_cursor == 0) {
-        g_return_val_if_fail ('v' == keyval, FALSE);
-        m_text = "v";
+        g_return_val_if_fail ('v' == keyval || 'V' == keyval, FALSE);
+        m_text.insert (m_cursor, keyval);
         m_cursor ++;
     } else {
-        g_return_val_if_fail ('v' == m_text[0], FALSE);
+        g_return_val_if_fail ('v' == m_text[0] || 'V' == m_text[0], FALSE);
         if ((keyval >= 'a' && keyval <= 'z') ||
             (keyval >= 'A' && keyval <= 'Z')) {
             m_text.insert (m_cursor, keyval);
@@ -533,9 +533,12 @@ EnglishEditor::processEnter (guint keyval)
     if (m_text.length () == 0)
         return FALSE;
 
-    Text text(m_text);
+    String word = m_text;
+    word.erase (0, 1);
+
+    Text text(word);
     commitText (text);
-    train (m_text.c_str (), m_train_factor);
+    train (word.c_str (), m_train_factor);
     reset ();
     return TRUE;
 }
@@ -596,14 +599,15 @@ EnglishEditor::updateStateFromInput (void)
         return FALSE;
     }
 
-    if ('v' != m_text[0]) {
+    if ('v' != m_text[0] && 'V' != m_text[0]) {
         g_warning ("v is expected in m_text string.\n");
         m_auxiliary_text = "";
         clearLookupTable ();
         return FALSE;
     }
 
-    m_auxiliary_text = "v";
+    m_auxiliary_text = m_text[0];
+
     if (1 == m_text.length ()) {
         clearLookupTable ();
 
