@@ -36,6 +36,7 @@ const gchar * const CONFIG_PAGE_SIZE                 = "lookup-table-page-size";
 const gchar * const CONFIG_REMEMBER_EVERY_INPUT      = "remember-every-input";
 const gchar * const CONFIG_SORT_OPTION               = "sort-candidate-option";
 const gchar * const CONFIG_SHOW_SUGGESTION           = "show-suggestion";
+const gchar * const CONFIG_EMOJI_CANDIDATE           = "emoji-candidate";
 const gchar * const CONFIG_SHIFT_SELECT_CANDIDATE    = "shift-select-candidate";
 const gchar * const CONFIG_MINUS_EQUAL_PAGE          = "minus-equal-page";
 const gchar * const CONFIG_COMMA_PERIOD_PAGE         = "comma-period-page";
@@ -62,6 +63,7 @@ const gchar * const CONFIG_CLEAR_USER_DATA           = "clear-user-data";
 const gchar * const CONFIG_MAIN_SWITCH               = "main-switch";
 const gchar * const CONFIG_LETTER_SWITCH             = "letter-switch";
 const gchar * const CONFIG_PUNCT_SWITCH              = "punct-switch";
+const gchar * const CONFIG_BOTH_SWITCH               = "both-switch";
 const gchar * const CONFIG_TRAD_SWITCH               = "trad-switch";
 
 const pinyin_option_t PINYIN_DEFAULT_OPTION =
@@ -101,6 +103,7 @@ LibPinyinConfig::initDefaultValues (void)
     m_remember_every_input = FALSE;
     m_sort_option = SORT_BY_PHRASE_LENGTH_AND_PINYIN_LENGTH_AND_FREQUENCY;
     m_show_suggestion = FALSE;
+    m_emoji_candidate = TRUE;
 
     m_shift_select_candidate = FALSE;
     m_minus_equal_page = TRUE;
@@ -124,6 +127,7 @@ LibPinyinConfig::initDefaultValues (void)
     m_main_switch = "<Shift>";
     m_letter_switch = "";
     m_punct_switch = "<Control>period";
+    m_both_switch = "";
     m_trad_switch = "<Control><Shift>f";
 }
 
@@ -209,6 +213,7 @@ LibPinyinConfig::readDefaultValues (void)
     }
 
     m_show_suggestion = read (CONFIG_SHOW_SUGGESTION, false);
+    m_emoji_candidate = read (CONFIG_EMOJI_CANDIDATE, true);
 
     m_dictionaries = read (CONFIG_DICTIONARIES, "");
     m_opencc_config = read (CONFIG_OPENCC_CONFIG, "s2t.json");
@@ -216,6 +221,7 @@ LibPinyinConfig::readDefaultValues (void)
     m_main_switch = read (CONFIG_MAIN_SWITCH, "<Shift>");
     m_letter_switch = read (CONFIG_LETTER_SWITCH, "");
     m_punct_switch = read (CONFIG_PUNCT_SWITCH, "<Control>period");
+    m_both_switch = read (CONFIG_BOTH_SWITCH, "");
     m_trad_switch = read (CONFIG_TRAD_SWITCH, "<Control><Shift>f");
 
     /* fuzzy pinyin */
@@ -274,6 +280,8 @@ LibPinyinConfig::valueChanged (const std::string &schema_id,
         }
     } else if (CONFIG_SHOW_SUGGESTION == name) {
         m_show_suggestion = normalizeGVariant (value, false);
+    } else if (CONFIG_EMOJI_CANDIDATE == name) {
+        m_emoji_candidate = normalizeGVariant (value, true);
     } else if (CONFIG_DICTIONARIES == name) {
         m_dictionaries = normalizeGVariant (value, std::string (""));
     } else if (CONFIG_OPENCC_CONFIG == name) {
@@ -284,6 +292,8 @@ LibPinyinConfig::valueChanged (const std::string &schema_id,
         m_letter_switch = normalizeGVariant (value, std::string (""));
     } else if (CONFIG_PUNCT_SWITCH == name) {
         m_punct_switch = normalizeGVariant (value, std::string ("<Control>period"));
+    } else if (CONFIG_BOTH_SWITCH == name) {
+        m_both_switch = normalizeGVariant (value, std::string (""));
     } else if (CONFIG_TRAD_SWITCH == name) {
         m_trad_switch = normalizeGVariant (value, std::string ("<Control><Shift>f"));
     }
