@@ -40,15 +40,16 @@ protected:
     gboolean processPunct (guint keyval, guint keycode, guint modifiers);
     gboolean processFunctionKey (guint keyval, guint keycode, guint modifiers);
 
-    void commit ();
-
-    virtual void updateAuxiliaryText (void);
+    virtual void updateAuxiliaryText (void) = 0;
     virtual void updateLookupTable (void);
     virtual void updatePreeditText (void);
 
     virtual gboolean processKeyEvent (guint keyval, guint keycode, guint modifiers);
 
     virtual void updatePinyin (void) = 0;
+    virtual void commit (const gchar *str);
+    using PhoneticEditor::commit;
+
 };
 
 };
